(in-package  :PSOL)
(use-package :oli)

(defparameter *keep-sketch* :no)

; debug output !

(defun debug-out (txt)
   (display txt)
)

(defun cat-path-name (path name) (format nil "~A/~A" path name) )


(defun select-wp (path wp-name)
  (let ((full-solid-name (cat-path-name path wp-name)))
    (current_wp full-solid-name))
)


; create a new empty working part or opens a existing one
(defun cond-new-part (asm-path file-path solid-name)  
  (unless (open-document asm-path file-path :part)
      (debug-out "create new part")
      (create_part :owner asm-path :name solid-name)     			
		)
)

; not yet impl.
;(defun finish-new-part (solid-name)      
;(save-new-part solid-name)
;)


(defun create-abs-sketch (dest-path sketch-name base-x base-y base-z x1 y1 z1 x2 y2 z2)
  (create_workplane :new :owner dest-path :name sketch-name
			:pt_pt_pt
			(make-gpnt3d :x base-x :y base-y :z base-z)
			(make-gpnt3d :x (+ x1 base-x) :y (+ y1 base-y) :z (+ z1 base-z))
			(make-gpnt3d :x (+ x2 base-x) :y (+ y2 base-y) :z (+ z2 base-z)))		  
)

; create a circle on the current plane !
(defun create-sketch-circle (x y r)  (circle :cen_rad (make-gpnt2d :x x :y y) r))

(defun create-sketch-line (x1 y1 x2 y2)  
    (line :two_points (make-gpnt2d :x x1 :y y1) (make-gpnt2d :x x2 :y y2))    
)

; create a arc based on 3 points
(defun create-sketch-arc-3p (x1 y1 x2 y2 x3 y3)
    (arc :3_pos
         (make-gpnt2d :x x1 :y y1)
         (make-gpnt2d :x x3 :y y3)
         (make-gpnt2d :x x2 :y y2))
)

(defun create-extrude-base (path sketch-name length side)    
    (select-wp path sketch-name)
    (extrude :auto_direction :yes	     
	     :wp (sd-inq-obj-pathname (sd-inq-curr-wp))
	     :distance_type :distance length
	     :direction side
	     :keep_profile *keep-sketch*
	     :keep_wp *keep-sketch*
	     )
)

(defun create-extrude-cut (path sketch-name length side)    
    (select-wp path sketch-name)
    (mill :auto_direction :yes	     
	     :wp (sd-inq-obj-pathname (sd-inq-curr-wp))
	     :distance_type :distance length
	     :direction side
	     :keep_profile *keep-sketch*
	     :keep_wp *keep-sketch*
	     )
)

(defun create-revolve-base (path sketch-name x1 y1 z1 x2 y2 z2 angle side)            
		(select-wp path sketch-name)
		(case side
		  (:+W
				(turn :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle angle
				)          
		 )
		 (:-W
				(turn :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle (- angle)
				)          
		 )
		 (:BOTH_SIDES
				(turn :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile :yes
				:keep_wp :yes
				:rotation_angle angle
				)
				(turn :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle (- angle)
				)          
		 )
	)
)

(defun create-revolve-cut (path sketch-name x1 y1 z1 x2 y2 z2 angle side)            
		(select-wp path sketch-name)
		(case side
		  (:+W
				(bore :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle angle
				)          
		 )
		 (:-W
				(bore :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle (- angle)
				)          
		 )
		 (:BOTH_SIDES
				(bore :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile :yes
				:keep_wp :yes
				:rotation_angle angle
				)
				(bore :axis
				:two_pta (make-gpnt3d :x x1 :y y1 :z z1) (make-gpnt3d :x x2 :y y2 :z z2)
				:wp (sd-inq-obj-pathname (sd-inq-curr-wp))
				:keep_profile *keep-sketch*
				:keep_wp *keep-sketch*
				:rotation_angle (- angle)
				)          
		 )
	)
)

(defun transform-document (full_name ox1 oy1 oz1 ox2 oy2 oz2 ox3 oy3 oz3
                                     nx1 ny1 nz1 nx2 ny2 nz2 nx3 ny3 nz3)
		(position_pa full_name 
		 :MATCH_THREE_PTS
			(make-gpnt3d :x ox1 :y oy1 :z oz1) (make-gpnt3d :x nx1 :y ny1 :z nz1)
			(make-gpnt3d :x ox2 :y oy2 :z oz2) (make-gpnt3d :x nx2 :y ny2 :z nz2)
			(make-gpnt3d :x ox3 :y oy3 :z oz3) (make-gpnt3d :x nx3 :y ny3 :z nz3)
		)
)
  
(create_assembly :owner "/" :name "SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0")
(create_part :owner "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" :name "SN5610_Pos3_5000_38_43_1_Pos3")
(set_part_base_color :parts "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN5610_Pos3_5000_38_43_1_Pos3" :color :rgb (gpnt3d 0 1 1))
(set_part_inst_color :parts "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN5610_Pos3_5000_38_43_1_Pos3" :color :rgb (gpnt3d 0 1 1))
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_1" 0 0 0 1 0 0 0 0 -1)
(create-sketch-line -18 0 -18 -72)
(create-sketch-line -18 -72 52.5 -72)
(create-sketch-line 52.5 -72 89 -92)
(create-sketch-line 89 -92 123 -92)
(create-sketch-line 123 -92 127 -88)
(create-sketch-line 127 -88 127 0)
(create-sketch-line 127 0 15 0)
(create-sketch-line 15 0 15 -6)
(create-sketch-line 15 -6 0 -6)
(create-sketch-line 0 -6 0 0)
(create-sketch-line 0 0 -18 0)
(create-extrude-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_1" 42.5 :BOTH_SIDES)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_2" -18 -42.5 72 1 0 0 0 1 0)
(create-sketch-circle 10 74 8.5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_2" 12 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_3" -18 -42.5 72 1 0 0 0 1 0)
(create-sketch-circle 10 11 8.5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_3" 12 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_4" -8 31.5 60 1 0 0 0 1 0)
(create-sketch-circle 0 0 5.5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_4" 92 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_5" -8 -31.5 60 1 0 0 0 1 0)
(create-sketch-circle 0 0 5.5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_5" 92 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_6" -18 -42.5 72 1 0 0 0 1 0)
(create-sketch-circle 40 74 5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_6" 92 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_7" -18 42.5 0 0 -1 0 0 0 1)
(create-sketch-circle 42.5 36 22.5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_7" 107 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_9" -18 42.5 72 1 0 0 0 1 0)
(create-sketch-line 58 0 58 -85)
(create-sketch-line 58 -85 70.5 -85)
(create-sketch-line 70.5 -85 70.5 0)
(create-sketch-line 70.5 0 58 0)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_9" 0.1 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_12" 0 0 92 1 0 0 0 1 0)
(create-sketch-circle 78.5 31.5 8.5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_12" 32 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_13" 0 0 92 1 0 0 0 1 0)
(create-sketch-circle 78.5 -31.5 8.5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_13" 32 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_14" 78.5 31.5 60 1 0 0 0 1 0)
(create-sketch-circle 0 0 5.5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_14" 92 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_15" 78.5 -31.5 60 1 0 0 0 1 0)
(create-sketch-circle 0 0 5.5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_15" 92 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_16" -18 -42.5 0 1 0 0 0 0 1)
(create-sketch-circle 25.5 36 5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_16" 2 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_17" -18 42.5 0 1 0 0 0 0 -1)
(create-sketch-circle 25.5 -36 5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_17" 2 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_18" 7.5 -40.5 36 1 0 0 0 0 1)
(create-sketch-arc-3p -4.4610789570501 1.1219512195122 -4.3704984948544 0.69257164816958 -3.9761790704142 0.5)
(create-sketch-line -3.9761790704142 0.5 -3.4641016151378 0.5)
(create-sketch-arc-3p -3.4641016151378 0.5 3.5 -8.5722444767566e-016 -3.4641016151378 -0.5)
(create-sketch-line -3.4641016151378 -0.5 -3.9761790704142 -0.5)
(create-sketch-arc-3p -3.9761790704142 -0.5 -4.3704984948544 -0.69257164816958 -4.4610789534157 -1.1219512339633)
(create-sketch-arc-3p -4.4610789534157 -1.1219512339633 4.6 -1.1266378455166e-015 -4.4610789570501 1.1219512195122)
(create-sketch-circle -3.9761790704142 -1 0.35)
(create-sketch-circle -3.9761790704142 1 0.35)
(create-extrude-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_18" 1 :+W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_19" 7.5 -40.5 36 1 0 0 0 0 1)
(create-sketch-circle 0 0 3.4)
(create-extrude-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_19" 1.5 :+W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_20" 7.5 40.5 36 1 0 0 0 0 -1)
(create-sketch-arc-3p -4.4610789570501 1.1219512195122 -4.3704984948544 0.69257164816958 -3.9761790704142 0.5)
(create-sketch-line -3.9761790704142 0.5 -3.4641016151378 0.5)
(create-sketch-arc-3p -3.4641016151378 0.5 3.5 -8.5722444767566e-016 -3.4641016151378 -0.5)
(create-sketch-line -3.4641016151378 -0.5 -3.9761790704142 -0.5)
(create-sketch-arc-3p -3.9761790704142 -0.5 -4.3704984948544 -0.69257164816958 -4.4610789534157 -1.1219512339633)
(create-sketch-arc-3p -4.4610789534157 -1.1219512339633 4.6 -1.1266378455166e-015 -4.4610789570501 1.1219512195122)
(create-sketch-circle -3.9761790704142 -1 0.35)
(create-sketch-circle -3.9761790704142 1 0.35)
(create-extrude-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_20" 1 :+W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_21" 7.5 40.5 36 1 0 0 0 0 -1)
(create-sketch-circle 0 0 3.4)
(create-extrude-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_21" 1.5 :+W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_22" 40 42.5 71.9 0 -1 0 1 0 0)
(create-sketch-circle 12 4 2)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_22" 0.2 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_23" 40 42.5 71.9 0 -1 0 1 0 0)
(create-sketch-circle 5 6.25 4)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_23" 0.2 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_24" 40 42.5 71.9 0 -1 0 1 0 0)
(create-sketch-circle 12 8.5 2)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_24" 0.2 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_25" 40 42.5 71.9 0 -1 0 1 0 0)
(create-sketch-circle 80 6.25 4)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_25" 0.2 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_26" 40 42.5 71.9 0 -1 0 1 0 0)
(create-sketch-circle 73 4 2)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_26" 0.2 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_27" 40 42.5 71.9 0 -1 0 1 0 0)
(create-sketch-circle 73 8.5 2)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_27" 0.2 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_28" 46.25 -37.5 71.7 0 -1 0 1 0 0)
(create-sketch-line -2.5 1.4433756729741 -2.5 -1.4433756729741)
(create-sketch-line -2.5 -1.4433756729741 0 -2.8867513459481)
(create-sketch-line 0 -2.8867513459481 2.5 -1.4433756729741)
(create-sketch-line 2.5 -1.4433756729741 2.5 1.4433756729741)
(create-sketch-line 2.5 1.4433756729741 0 2.8867513459481)
(create-sketch-line 0 2.8867513459481 -2.5 1.4433756729741)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_28" 1.5 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_29" 46.25 37.5 71.7 0 -1 0 1 0 0)
(create-sketch-line -2.5 1.4433756729741 -2.5 -1.4433756729741)
(create-sketch-line -2.5 -1.4433756729741 0 -2.8867513459481)
(create-sketch-line 0 -2.8867513459481 2.5 -1.4433756729741)
(create-sketch-line 2.5 -1.4433756729741 2.5 1.4433756729741)
(create-sketch-line 2.5 1.4433756729741 0 2.8867513459481)
(create-sketch-line 0 2.8867513459481 -2.5 1.4433756729741)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_29" 1.5 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_30" -18 -42.5 0 1 0 0 0 0 1)
(create-sketch-circle 127 74 9)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_30" 85.2 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_31" -18 -42.5 72 1 0 0 0 1 0)
(create-sketch-circle 79 11 5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_31" 92 :BOTH_SIDES)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_8" 127 -42.5 0 0 1 0 0 0 1)
(create-sketch-arc-3p 21.5 56.25 14.845931683792 51.55092918767 12.5 43.75)
(create-sketch-line 12.5 43.75 12.5 17)
(create-sketch-arc-3p 12.5 17 16.161165235168 8.1611652351682 25 4.5)
(create-sketch-line 25 4.5 60 4.5)
(create-sketch-arc-3p 60 4.5 68.838834764832 8.1611652351682 72.5 17)
(create-sketch-line 72.5 17 72.5 43.75)
(create-sketch-arc-3p 72.5 43.75 70.154068316208 51.55092918767 63.5 56.25)
(create-sketch-line 63.5 56.25 63.5 92)
(create-sketch-line 63.5 92 21.5 92)
(create-sketch-line 21.5 92 21.5 56.25)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_8" 38 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_10" -18 42.5 0 1 0 0 0 0 -1)
(create-sketch-line 58 -53.5 58 -78.5)
(create-sketch-line 58 -78.5 70.5 -78.5)
(create-sketch-line 70.5 -78.5 70.5 -53.5)
(create-sketch-line 70.5 -53.5 58 -53.5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_10" 0.1 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_35" -18 -42.5 0 1 0 0 0 0 1)
(create-sketch-line 58 53.5 70.5 53.5)
(create-sketch-line 70.5 53.5 70.5 83.5)
(create-sketch-line 70.5 83.5 58 83.5)
(create-sketch-line 58 83.5 58 53.5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_35" 0.1 :-W)
(transform-document "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN5610_Pos3_5000_38_43_1_Pos3" 0 0 0 1 0 0 0 1 0 0 0 0 1 0 0 0 1 0)
(create_part :owner "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" :name "SN5610_Pos4_5000_38_43_1_Pos4_SX_0")
(set_part_base_color :parts "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN5610_Pos4_5000_38_43_1_Pos4_SX_0" :color :rgb (gpnt3d 1 0.50196081399918 0.25098040699959))
(set_part_inst_color :parts "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN5610_Pos4_5000_38_43_1_Pos4_SX_0" :color :rgb (gpnt3d 1 0.50196081399918 0.25098040699959))
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_3" 0 0 0 1 0 0 0 0 -1)
(create-sketch-arc-3p -19 0 -13.727922061358 -12.727922061358 -1 -18)
(create-sketch-line -1 -18 21 -18)
(create-sketch-line 21 -18 21 -37)
(create-sketch-arc-3p 21 -37 33.763184230455 -50.945260368749 48.781469536029 -39.463959704926)
(create-sketch-line 48.781469536029 -39.463959704926 60.581469536029 26.536040295074)
(create-sketch-arc-3p 60.581469536029 26.536040295074 49.888115680045 42.655165379689 33.299391273496 32.705882352941)
(create-sketch-arc-3p 33.299391273496 32.705882352941 26.139588630307 22.095875488711 14.01280737849 18)
(create-sketch-line 14.01280737849 18 -11.71 18)
(create-sketch-arc-3p -11.71 18 -16.86480843485 15.86480843485 -19 10.71)
(create-sketch-line -19 10.71 -19 0)
(create-extrude-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_3" 20.9 :BOTH_SIDES)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_4" 0 20.9 0 1 0 0 0 0 -1)
(create-sketch-circle 46.8 29 9)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_4" 0.01 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_5" 0 20.9 0 1 0 0 0 0 -1)
(create-sketch-circle 35 -37 9)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_5" 0.01 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_6" 0 -20.9 0 1 0 0 0 0 -1)
(create-sketch-circle 46.8 29 9)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_6" 0.01 :+W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_7" 0 -20.9 0 1 0 0 0 0 -1)
(create-sketch-circle 35 -37 9)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_7" 0.01 :+W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_8" 0 -20.9 0 1 0 0 0 0 -1)
(create-sketch-circle 0 0 9)
(create-extrude-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_8" 21.7 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_9" 0 20.9 0 1 0 0 0 0 -1)
(create-sketch-circle 0 0 9)
(create-extrude-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_9" 21.7 :+W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_2" 0 0 0 1 0 0 0 0 -1)
(create-sketch-circle 35 -37 17.1)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_2" 9 :BOTH_SIDES)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_11" 0 0 0 1 0 0 0 0 -1)
(create-sketch-circle 35 -37 17)
(create-extrude-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_11" 9 :BOTH_SIDES)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_12" 0 0 0 1 0 0 0 0 -1)
(create-sketch-circle 46.8 29 17.1)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_12" 8.9 :BOTH_SIDES)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_13" 0 0 0 1 0 0 0 0 -1)
(create-sketch-circle 46.8 29 17)
(create-extrude-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_13" 8.9 :BOTH_SIDES)
(transform-document "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN5610_Pos4_5000_38_43_1_Pos4_SX_0" 0 0 0 1 0 0 0 1 0 109 0 74 110 0 74 109 -1 74)
(create_part :owner "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" :name "SN5610_Pos2_5000_38_43_1_Pos2_SX_0")
(set_part_base_color :parts "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN5610_Pos2_5000_38_43_1_Pos2_SX_0" :color :rgb (gpnt3d 1 1 0))
(set_part_inst_color :parts "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN5610_Pos2_5000_38_43_1_Pos2_SX_0" :color :rgb (gpnt3d 1 1 0))
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_1" 0 0 0 0 0 -1 0 1 0)
(create-sketch-line -145 0 -145 22)
(create-sketch-line -145 22 -144.5 22.5)
(create-sketch-line -144.5 22.5 -8 22.5)
(create-sketch-line -8 22.5 -8 22)
(create-sketch-line -8 22 -5 22)
(create-sketch-line -5 22 -5 22.5)
(create-sketch-line -5 22.5 -0.5 22.5)
(create-sketch-line -0.5 22.5 0 22)
(create-sketch-line 0 22 0 0)
(create-sketch-line 0 0 -145 0)
(create-revolve-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_1" 0 0 0 0 0 145 360 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_4" 0 0 145 0 1 0 -1 0 0)
(create-sketch-circle 0 15 4)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_4" 30 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_5" 0 0 145 0 1 0 -1 0 0)
(create-sketch-circle 0 -15 4)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_5" 30 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_6" 0 0 145 0 1 0 -1 0 0)
(create-sketch-circle 15 0 4)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_6" 40 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_7" 0 0 145 0 1 0 -1 0 0)
(create-sketch-circle -15 0 4)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_7" 40 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_8" 0 0 0 0 1 0 1 0 0)
(create-sketch-line -17.642278764377 17 17.642278764377 17)
(create-sketch-arc-3p 17.642278764377 17 1.5001427834324e-015 24.5 -17.642278764377 17)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_8" 91 :-W)
(transform-document "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN5610_Pos2_5000_38_43_1_Pos2_SX_0" 0 0 0 1 0 0 0 1 0 127 0 36 127 0 37 127 1 36)
(create_part :owner "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" :name "SN5610_Pos1_5000_38_43_1_Pos1")
(set_part_base_color :parts "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN5610_Pos1_5000_38_43_1_Pos1" :color :rgb (gpnt3d 0.23137255012989 0.58039218187332 0.41568627953529))
(set_part_inst_color :parts "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN5610_Pos1_5000_38_43_1_Pos1" :color :rgb (gpnt3d 0.23137255012989 0.58039218187332 0.41568627953529))
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_1" 0 0 0 1 0 0 0 1 0)
(create-sketch-line -35 -30 35 -30)
(create-sketch-line 35 -30 35 30)
(create-sketch-line 35 30 -35 30)
(create-sketch-line -35 30 -35 -30)
(create-sketch-circle 15 0 4)
(create-sketch-circle 0 -15 4.25)
(create-sketch-circle 0 15 4.25)
(create-sketch-circle -15 0 4)
(create-extrude-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_1" 15 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_2" 35 -30 -15 -1 0 0 0 1 0)
(create-sketch-circle 35 45 6.75)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_2" 8 :-W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_4" 35 -30 -15 -1 0 0 0 1 0)
(create-sketch-circle 35 15 6.75)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Skizze_4" 8 :-W)
(transform-document "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN5610_Pos1_5000_38_43_1_Pos1" 0 0 0 1 0 0 0 1 0 -18 0 36 -18 -1 36 -18 0 35)
(create_part :owner "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" :name "SN3450_M8_30_Cylinder_head_cap_screw")
(set_part_base_color :parts "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN3450_M8_30_Cylinder_head_cap_screw" :color :rgb (gpnt3d 1 0 0))
(set_part_inst_color :parts "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN3450_M8_30_Cylinder_head_cap_screw" :color :rgb (gpnt3d 1 0 0))
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Sketch_1" 0 0 0 0 0 -1 0 1 0)
(create-sketch-line -8 0 -8 5.7)
(create-sketch-arc-3p -8 5.7 -7.7656854249492 6.2656854249492 -7.2 6.5)
(create-sketch-line -7.2 6.5 0 6.5)
(create-sketch-line 0 6.5 0 4)
(create-sketch-line 0 4 29.4 4)
(create-sketch-line 29.4 4 30 3.4)
(create-sketch-line 30 3.4 30 0)
(create-sketch-line 30 0 -8 0)
(create-revolve-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Sketch_1" 0 0 -30 0 0 8 360 :+W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Sketch_2" 0 0 8 0 1 0 -1 0 0)
(create-sketch-line -3 1.7320508075689 -3 -1.7320508075689)
(create-sketch-line -3 -1.7320508075689 0 -3.4641016151378)
(create-sketch-line 0 -3.4641016151378 3 -1.7320508075689)
(create-sketch-line 3 -1.7320508075689 3 1.7320508075689)
(create-sketch-line 3 1.7320508075689 0 3.4641016151378)
(create-sketch-line 0 3.4641016151378 -3 1.7320508075689)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Sketch_2" 5 :BOTH_SIDES)
(transform-document "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN3450_M8_30_Cylinder_head_cap_screw" 0 0 0 1 0 0 0 1 0 -25 0 21 -25 0 22 -25 1 21)
(CREATE_MULTIPLE_PA :SHARE :NAME "SN3450_M8_30_Cylinder_head_cap_screw_0" :OWNER "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" :SOURCE "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN3450_M8_30_Cylinder_head_cap_screw")
(transform-document "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN3450_M8_30_Cylinder_head_cap_screw_0" 0 0 0 1 0 0 0 1 0 7.105427357601e-015 0 30 1 0 30 7.105427357601e-015 1 30)
(create_part :owner "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" :name "SN1975_8_40_Dowel_pin")
(set_part_base_color :parts "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN1975_8_40_Dowel_pin" :color :rgb (gpnt3d 1 0.50196081399918 0))
(set_part_inst_color :parts "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN1975_8_40_Dowel_pin" :color :rgb (gpnt3d 1 0.50196081399918 0))
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Sketch_1" 0 0 0 1 0 0 0 0 -1)
(create-sketch-line 9.9604740410711 0 8.8 2.01)
(create-sketch-line 8.8 2.01 0.8 2.01)
(create-sketch-line 0.8 2.01 0.8 3.25)
(create-sketch-line 0.8 3.25 0 3.25)
(create-sketch-line 0 3.25 0 3.6784609690827)
(create-sketch-line 0 3.6784609690827 1.2 4)
(create-sketch-line 1.2 4 37.56 4)
(create-sketch-line 37.56 4 39.360965010976 3.5174328797122)
(create-sketch-arc-3p 39.360965010976 3.5174328797122 39.838944305914 1.7875052293964 40 0)
(create-sketch-line 40 0 9.9604740410711 0)
(create-revolve-base "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Sketch_1" 40 0 0 9.9604740410711 0 0 360 :+W)
(create-abs-sketch "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Sketch_3" 0.79999999999999 0 0 0 0 -1 0 -1 0)
(create-sketch-line 3.9686269665969 0.5 3.9686269665969 -0.5)
(create-sketch-line 3.9686269665969 -0.5 4.9749371855331 -0.5)
(create-sketch-arc-3p 4.9749371855331 -0.5 5 -1.2246063538224e-015 4.9749371855331 0.5)
(create-sketch-line 4.9749371855331 0.5 3.9686269665969 0.5)
(create-extrude-cut "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" "Sketch_3" 40 :BOTH_SIDES)
(transform-document "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN1975_8_40_Dowel_pin" 0 0 0 1 0 0 0 1 0 -30.5 15 36 -29.5 15 36 -30.5 16 36)
(CREATE_MULTIPLE_PA :SHARE :NAME "SN1975_8_40_Dowel_pin_1" :OWNER "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/" :SOURCE "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN1975_8_40_Dowel_pin")
(transform-document "/SN5610_5000_38_Lateral_slide_unit_with_cam_system_SX_0/SN1975_8_40_Dowel_pin_1" 0 0 0 1 0 0 0 1 0 -7.105427357601e-015 -30 0 0.99999999999999 -30 0 -7.105427357601e-015 -29 0)
